@@ -16,10 +16,10 @@ pub struct ExtendExpirationCtx<'info> {
     #[account(mut, constraint = time_invalidator.token_manager == token_manager.key() @ ErrorCode::InvalidTimeInvalidator)]
     time_invalidator: Box<Account<'info, TimeInvalidator>>,
 
-    #[account(mut, constraint = payment_token_account.mint == time_invalidator.extension_payment_mint.unwrap() @ ErrorCode::InvalidPaymentTokenAccount)]
+    #[account(mut, constraint = payment_token_account.mint == time_invalidator.extension_payment_mint.expect("No extension mint") @ ErrorCode::InvalidPaymentTokenAccount)]
     payment_token_account: Box<Account<'info, TokenAccount>>,
     #[account(mut, constraint =
-        payment_manager_token_account.mint == time_invalidator.extension_payment_mint.unwrap()
+        payment_manager_token_account.mint == time_invalidator.extension_payment_mint.expect("No extension mint")
         && payment_manager_token_account.owner == time_invalidator.payment_manager
         && assert_payment_manager(&payment_manager_token_account.owner)
         @ ErrorCode::InvalidPaymentManagerTokenAccount
@@ -30,7 +30,7 @@ pub struct ExtendExpirationCtx<'info> {
     payer: Signer<'info>,
     #[account(mut, constraint =
       payer_token_account.owner == payer.key()
-      && payer_token_account.mint == time_invalidator.extension_payment_mint.unwrap()
+      && payer_token_account.mint == time_invalidator.extension_payment_mint.expect("No extension mint")
       @ ErrorCode::InvalidPayerTokenAccount
   )]
     payer_token_account: Box<Account<'info, TokenAccount>>,
@@ -48,28 +48,47 @@ pub fn handler(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> Result
     }
 
     let time_to_add = payment_amount
-        .checked_mul(time_invalidator.extension_duration_seconds.unwrap())
-        .unwrap()
-        .checked_div(time_invalidator.extension_payment_amount.unwrap())
-        .unwrap();
+        .checked_mul(time_invalidator.extension_duration_seconds.expect("No extension duration"))
+        .expect("Multiplication error")
+        .checked_div(time_invalidator.extension_payment_amount.expect("No extension amount"))
+        .expect("Division error");
 
-    if time_invalidator.disable_partial_extension != None && time_invalidator.disable_partial_extension.unwrap() && time_to_add % time_invalidator.extension_duration_seconds.unwrap() != 0 {
+    if time_invalidator.disable_partial_extension != None
+        && time_invalidator.disable_partial_extension.unwrap()
+        && time_to_add
+            .checked_rem(time_invalidator.extension_duration_seconds.expect("No extension duration"))
+            .expect("Remainder error")
+            != 0
+    {
         return Err(error!(ErrorCode::InvalidExtensionAmount));
     }
 
-    let mut expiration = ctx.accounts.token_manager.state_changed_at.checked_add(time_invalidator.duration_seconds.unwrap()).unwrap();
+    let mut expiration = ctx
+        .accounts
+        .token_manager
+        .state_changed_at
+        .checked_add(time_invalidator.duration_seconds.expect("No duration set"))
+        .expect("Add error");
     if time_invalidator.expiration != None {
         expiration = time_invalidator.expiration.unwrap();
     }
-    let new_expiration = Some(expiration + time_to_add as i64);
+    let new_expiration = Some(expiration.checked_add(time_to_add as i64).expect("Addition error"));
 
     if time_invalidator.max_expiration != None && new_expiration > time_invalidator.max_expiration {
         return Err(error!(ErrorCode::InvalidExtendExpiration));
     }
 
-    let provider_fee = time_invalidator.extension_payment_amount.unwrap() * (PROVIDER_FEE / FEE_SCALE);
-    let recipient_fee = time_invalidator.extension_payment_amount.unwrap() * (RECIPIENT_FEE / FEE_SCALE);
-    if provider_fee.checked_add(recipient_fee).unwrap() > 0 {
+    let provider_fee = time_invalidator
+        .extension_payment_amount
+        .expect("No extension amount")
+        .checked_mul(PROVIDER_FEE.checked_div(FEE_SCALE).expect("Division error"))
+        .expect("Multiplication error");
+    let recipient_fee = time_invalidator
+        .extension_payment_amount
+        .expect("No extension amount")
+        .checked_mul(RECIPIENT_FEE.checked_div(FEE_SCALE).expect("Division error"))
+        .expect("Multiplication error");
+    if provider_fee.checked_add(recipient_fee).expect("Add error") > 0 {
         let cpi_accounts = Transfer {
             from: ctx.accounts.payer_token_account.to_account_info(),
             to: ctx.accounts.payment_manager_token_account.to_account_info(),
@@ -77,7 +96,7 @@ pub fn handler(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> Result
         };
         let cpi_program = ctx.accounts.token_program.to_account_info();
         let cpi_context = CpiContext::new(cpi_program, cpi_accounts);
-        token::transfer(cpi_context, provider_fee.checked_add(recipient_fee).unwrap())?;
+        token::transfer(cpi_context, provider_fee.checked_add(recipient_fee).expect("Add error"))?;
     }
 
     let cpi_accounts = Transfer {
@@ -88,7 +107,7 @@ pub fn handler(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> Result
 
     let cpi_program = ctx.accounts.token_program.to_account_info();
     let cpi_context = CpiContext::new(cpi_program, cpi_accounts);
-    token::transfer(cpi_context, payment_amount.checked_sub(recipient_fee).unwrap())?;
+    token::transfer(cpi_context, payment_amount.checked_sub(recipient_fee).expect("Sub error"))?;
 
     time_invalidator.expiration = new_expiration;
     Ok(())
