@@ -15,7 +15,7 @@ pub struct InvalidateCtx<'info> {
     #[account(mut,
         constraint = time_invalidator.expiration != None && Clock::get().unwrap().unix_timestamp >= time_invalidator.expiration.unwrap()
         || time_invalidator.max_expiration != None && Clock::get().unwrap().unix_timestamp >= time_invalidator.max_expiration.unwrap()
-        || time_invalidator.expiration == None && token_manager.state == TokenManagerState::Claimed as u8 && Clock::get().unwrap().unix_timestamp >= token_manager.state_changed_at + time_invalidator.duration_seconds.unwrap()
+        || time_invalidator.expiration == None && token_manager.state == TokenManagerState::Claimed as u8 && Clock::get().unwrap().unix_timestamp >= token_manager.state_changed_at.checked_add(time_invalidator.duration_seconds.expect("No extension duration")).expect("Addition error")
         @ ErrorCode::InvalidTimeInvalidator
     )]
     time_invalidator: Box<Account<'info, TimeInvalidator>>,
@@ -38,6 +38,7 @@ pub struct InvalidateCtx<'info> {
     /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     recipient_token_account: UncheckedAccount<'info>,
+    rent: Sysvar<'info, Rent>,
 }
 
 pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> Result<()> {
@@ -54,6 +55,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
         invalidator: ctx.accounts.time_invalidator.to_account_info(),
         collector: ctx.accounts.invalidator.to_account_info(),
         token_program: ctx.accounts.token_program.to_account_info(),
+        rent: ctx.accounts.rent.to_account_info(),
     };
     let cpi_ctx = CpiContext::new(ctx.accounts.cardinal_token_manager.to_account_info(), cpi_accounts)
         .with_remaining_accounts(ctx.remaining_accounts.to_vec())
